==> ambition_auth-0.1.19-py3-none-any.whl: ambition_auth/codenames/auditor.py <==
from edc_permissions.codenames import auditor

auditor += [
    "ambition_ae.view_aefollowup",
    "ambition_ae.view_aeinitial",
    "ambition_ae.view_aesusar",
    "ambition_ae.view_aetmg",
    "ambition_ae.view_antibiotictreatment",
    "ambition_ae.view_historicalaefollowup",
    "ambition_ae.view_historicalaeinitial",
    "ambition_ae.view_historicalaesusar",
    "ambition_ae.view_historicalaetmg",
    "ambition_ae.view_historicalrecurrencesymptom",
    "ambition_ae.view_meningitissymptom",
    "ambition_ae.view_neurological",
    "ambition_ae.view_recurrencesymptom",
    "ambition_lists.view_abnormalresultsreason",
    "ambition_lists.view_antibiotic",
    "ambition_lists.view_cxrtype",
    "ambition_lists.view_day14medication",
    "ambition_lists.view_infiltratelocation",
    "ambition_lists.view_medication",
    "ambition_lists.view_misseddoses",
    "ambition_lists.view_neurological",
    "ambition_lists.view_otherdrug",
    "ambition_lists.view_significantnewdiagnosis",
    "ambition_lists.view_symptom",
    "ambition_prn.view_amphotericinmisseddoses",
    "ambition_prn.view_deathreport",
    "ambition_prn.view_deathreporttmg",
    "ambition_prn.view_fluconazolemisseddoses",
    "ambition_prn.view_flucytosinemisseddoses",
    "ambition_prn.view_historicalamphotericinmisseddoses",
    "ambition_prn.view_historicaldeathreport",
    "ambition_prn.view_historicaldeathreporttmg",
    "ambition_prn.view_historicalfluconazolemisseddoses",
    "ambition_prn.view_historicalflucytosinemisseddoses",
    "ambition_prn.view_historicalonschedule",
    "ambition_prn.view_historicalonschedulew10",
    "ambition_prn.view_historicalprotocoldeviationviolation",
    "ambition_prn.view_historicalsignificantdiagnoses",
    "ambition_prn.view_historicalstudyterminationconclusion",
    "ambition_prn.view_historicalstudyterminationconclusionw10",
    "ambition_prn.view_onschedule",
    "ambition_prn.view_onschedulew10",
    "ambition_prn.view_protocoldeviationviolation",
    "ambition_prn.view_significantdiagnoses",
    "ambition_prn.view_studyterminationconclusion",
    "ambition_prn.view_studyterminationconclusionw10",
    "ambition_subject.view_amphotericinmisseddoses",
    "ambition_subject.view_bloodresult",
    "ambition_subject.view_education",
    "ambition_subject.view_educationhoh",
    "ambition_subject.view_fluconazolemisseddoses",
    "ambition_subject.view_flucytosinemisseddoses",
    "ambition_subject.view_followup",
    "ambition_subject.view_followupdiagnoses",
    "ambition_subject.view_historicalamphotericinmisseddoses",
    "ambition_subject.view_historicalbloodresult",
    "ambition_subject.view_historicaleducation",
    "ambition_subject.view_historicaleducationhoh",
    "ambition_subject.view_historicalfluconazolemisseddoses",
    "ambition_subject.view_historicalflucytosinemisseddoses",
    "ambition_subject.view_historicalfollowup",
    "ambition_subject.view_historicalfollowupdiagnoses",
    "ambition_subject.view_historicallumbarpuncturecsf",
    "ambition_subject.view_historicalmedicalexpenses",
    "ambition_subject.view_historicalmedicalexpensestwo",
    "ambition_subject.view_historicalmedicalexpensestwodetail",
    "ambition_subject.view_historicalmicrobiology",
    "ambition_subject.view_historicalpatienthistory",
    "ambition_subject.view_historicalpkpdcrf",
    "ambition_subject.view_historicalpkpdextrasamples",
    "ambition_subject.view_historicalpreviousopportunisticinfection",
    "ambition_subject.view_historicalradiology",
    "ambition_subject.view_historicalsignificantdiagnoses",
    "ambition_subject.view_historicalsubjectrequisition",
    "ambition_subject.view_historicalsubjectvisit",
    "ambition_subject.view_historicalweek16",
    "ambition_subject.view_historicalweek2",
    "ambition_subject.view_historicalweek4",
    "ambition_subject.view_historicalweek4diagnoses",
    "ambition_subject.view_lumbarpuncturecsf",
    "ambition_subject.view_medicalexpenses",
    "ambition_subject.view_medicalexpensestwo",
    "ambition_subject.view_medicalexpensestwodetail",
    "ambition_subject.view_microbiology",
    "ambition_subject.view_patienthistory",
    "ambition_subject.view_pkpdcrf",
    "ambition_subject.view_pkpdextrasamples",
    "ambition_subject.view_previousopportunisticinfection",
    "ambition_subject.view_radiology",
    "ambition_subject.view_significantdiagnoses",
    "ambition_subject.view_subjectrequisition",
    "ambition_subject.view_subjectvisit",
    "ambition_subject.view_week16",
    "ambition_subject.view_week2",
    "ambition_subject.view_week4",
    "ambition_subject.view_week4diagnoses",
]
auditor.sort()

==> ambition_auth-0.2.1-py3-none-any.whl: ambition_auth/codenames/auditor.py <==
from edc_auth.codenames import auditor

auditor += [
    "ambition_ae.view_aefollowup",
    "ambition_ae.view_aeinitial",
    "ambition_ae.view_aesusar",
    "ambition_ae.view_aetmg",
    "ambition_ae.view_antibiotictreatment",
    "ambition_ae.view_deathreport",
    "ambition_ae.view_deathreporttmg",
    "ambition_ae.view_deathreporttmgsecond",
    "ambition_ae.view_historicalaefollowup",
    "ambition_ae.view_historicalaeinitial",
    "ambition_ae.view_historicalaesusar",
    "ambition_ae.view_historicalaetmg",
    "ambition_ae.view_historicaldeathreport",
    "ambition_ae.view_historicaldeathreporttmg",
    "ambition_ae.view_historicaldeathreporttmgsecond",
    "ambition_ae.view_historicalrecurrencesymptom",
    "ambition_ae.view_meningitissymptom",
    "ambition_ae.view_neurological",
    "ambition_ae.view_recurrencesymptom",
    "ambition_lists.view_abnormalresultsreason",
    # "ambition_lists.view_aeclassification",
    "ambition_lists.view_antibiotic",
    "ambition_lists.view_arvregimens",
    # "ambition_lists.view_causeofdeath",
    "ambition_lists.view_cxrtype",
    "ambition_lists.view_day14medication",
    "ambition_lists.view_infiltratelocation",
    "ambition_lists.view_medication",
    "ambition_lists.view_misseddoses",
    "ambition_lists.view_neurological",
    "ambition_lists.view_otherdrug",
    # "ambition_lists.view_saereason",
    "ambition_lists.view_significantnewdiagnosis",
    "ambition_lists.view_symptom",
    "ambition_prn.view_amphotericinmisseddoses",
    "ambition_prn.view_fluconazolemisseddoses",
    "ambition_prn.view_flucytosinemisseddoses",
    "ambition_prn.view_historicalamphotericinmisseddoses",
    "ambition_prn.view_historicalfluconazolemisseddoses",
    "ambition_prn.view_historicalflucytosinemisseddoses",
    "ambition_prn.view_historicalonschedule",
    "ambition_prn.view_historicalonschedulew10",
    "ambition_prn.view_historicalprotocoldeviationviolation",
    "ambition_prn.view_historicalsignificantdiagnoses",
    "ambition_prn.view_historicalstudyterminationconclusion",
    "ambition_prn.view_historicalstudyterminationconclusionw10",
    "ambition_prn.view_onschedule",
    "ambition_prn.view_onschedulew10",
    "ambition_prn.view_protocoldeviationviolation",
    "ambition_prn.view_significantdiagnoses",
    "ambition_prn.view_studyterminationconclusion",
    "ambition_prn.view_studyterminationconclusionw10",
    "ambition_subject.view_amphotericinmisseddoses",
    "ambition_subject.view_bloodresult",
    "ambition_subject.view_education",
    "ambition_subject.view_educationhoh",
    "ambition_subject.view_fluconazolemisseddoses",
    "ambition_subject.view_flucytosinemisseddoses",
    "ambition_subject.view_followup",
    "ambition_subject.view_followupdiagnoses",
    "ambition_subject.view_historicalamphotericinmisseddoses",
    "ambition_subject.view_historicalbloodresult",
    "ambition_subject.view_historicaleducation",
    "ambition_subject.view_historicaleducationhoh",
    "ambition_subject.view_historicalfluconazolemisseddoses",
    "ambition_subject.view_historicalflucytosinemisseddoses",
    "ambition_subject.view_historicalfollowup",
    "ambition_subject.view_historicalfollowupdiagnoses",
    "ambition_subject.view_historicallumbarpuncturecsf",
    "ambition_subject.view_historicalmedicalexpenses",
    "ambition_subject.view_historicalmedicalexpensestwo",
    "ambition_subject.view_historicalmedicalexpensestwodetail",
    "ambition_subject.view_historicalmicrobiology",
    "ambition_subject.view_historicalpatienthistory",
    "ambition_subject.view_historicalpkpdcrf",
    "ambition_subject.view_historicalpkpdextrasamples",
    "ambition_subject.view_historicalpreviousopportunisticinfection",
    "ambition_subject.view_historicalradiology",
    "ambition_subject.view_historicalsignificantdiagnoses",
    "ambition_subject.view_historicalsubjectrequisition",
    "ambition_subject.view_historicalsubjectvisit",
    "ambition_subject.view_historicalweek16",
    "ambition_subject.view_historicalweek2",
    "ambition_subject.view_historicalweek4",
    "ambition_subject.view_historicalweek4diagnoses",
    "ambition_subject.view_lumbarpuncturecsf",
    "ambition_subject.view_medicalexpenses",
    "ambition_subject.view_medicalexpensestwo",
    "ambition_subject.view_medicalexpensestwodetail",
    "ambition_subject.view_microbiology",
    "ambition_subject.view_patienthistory",
    "ambition_subject.view_pkpdcrf",
    "ambition_subject.view_pkpdextrasamples",
    "ambition_subject.view_previousopportunisticinfection",
    "ambition_subject.view_radiology",
    "ambition_subject.view_significantdiagnoses",
    "ambition_subject.view_subjectrequisition",
    "ambition_subject.view_subjectvisit",
    "ambition_subject.view_week16",
    "ambition_subject.view_week2",
    "ambition_subject.view_week4",
    "ambition_subject.view_week4diagnoses",
    "edc_dashboard.view_screening_listboard",
    "edc_dashboard.view_subject_listboard",
    "edc_dashboard.view_tmg_listboard",
    "edc_navbar.nav_ae_section",
    "edc_navbar.nav_screening_section",
    "edc_navbar.nav_subject_section",
    "edc_navbar.nav_tmg_section",
]
auditor.sort()
